@@ -14,11 +14,21 @@ rm -f ./*tar.gz
 # create the src.rpm
 rpmbuild \
     -D "_srcrpmdir $PWD/output" \
+    -D "_sourcedir $PWD/" \
     -D "_topmdir $PWD/rpmbuild" \
-    -ts ./*.gz
+    -bs ./python-ovirt-engine-sdk4.spec
+
+if [[ "$(rpm --eval "%dist")" == ".el8" ]]; then
+# create the src.rpm
+rpmbuild \
+    -D "_srcrpmdir $PWD/output" \
+    -D "_sourcedir $PWD/" \
+    -D "_topmdir $PWD/rpmbuild" \
+    -bs ./python38-ovirt-engine-sdk4.spec
+fi
 
 # install any build requirements
-yum-builddep output/*src.rpm
+dnf builddep output/*src.rpm
 
 # create the rpms
 rpmbuild \
